@@ -1,10 +1,7 @@
-# -*- coding: utf-8 -*-
 """Private keys for the security serializer."""
-from __future__ import absolute_import, unicode_literals
-
 from cryptography.hazmat.backends import default_backend
 from cryptography.hazmat.primitives import serialization
-from cryptography.hazmat.primitives.asymmetric import padding
+from cryptography.hazmat.primitives.asymmetric import padding, rsa
 from kombu.utils.encoding import ensure_bytes
 
 from .utils import reraise_errors
@@ -12,7 +9,7 @@ from .utils import reraise_errors
 __all__ = ('PrivateKey',)
 
 
-class PrivateKey(object):
+class PrivateKey:
     """Represents a private key."""
 
     def __init__(self, key, password=None):
@@ -21,15 +18,18 @@ class PrivateKey(object):
         ):
             self._key = serialization.load_pem_private_key(
                 ensure_bytes(key),
-                password=password,
+                password=ensure_bytes(password),
                 backend=default_backend())
 
+            if not isinstance(self._key, rsa.RSAPrivateKey):
+                raise ValueError("Non-RSA keys are not supported.")
+
     def sign(self, data, digest):
         """Sign string containing data."""
         with reraise_errors('Unable to sign data: {0!r}'):
 
-            padd = padding.PSS(
+            pad = padding.PSS(
                 mgf=padding.MGF1(digest),
                 salt_length=padding.PSS.MAX_LENGTH)
 
-            return self._key.sign(ensure_bytes(data), padd, digest)
+            return self._key.sign(ensure_bytes(data), pad, digest)
